@@ -20,14 +20,14 @@ DataCubeGeom2 <- R6::R6Class(
                           cache_file = NULL,
                           layer = 8, digest = TRUE, ...){
       # Make sure value is from 0 to 255
-      value = floor((value - min(value)) / (max(value) - min(value)) * 255)
+      value <- floor((value - min(value)) / (max(value) - min(value)) * 255)
       super$initialize(name = name, value = value, dim = dim, half_size = half_size,
                        group = group, position = position, cache_file = cache_file,
                        layer = layer, digest = digest, ...)
     },
 
     to_list = function(){
-      re = super$to_list()
+      re <- super$to_list()
       c(
         re,
         list(
