@@ -22,11 +22,11 @@ SphereGeom <- R6::R6Class(
     initialize = function(name, position = c(0,0,0), radius = 5, ...){
       super$initialize(name, position = position, ...)
 
-      self$radius = radius
-      other_args = list(...)
+      self$radius <- radius
+      other_args <- list(...)
 
-      self$width_segments = get2('width_segments', other_args, ifnotfound = 10)
-      self$height_segments = get2('height_segments', other_args, ifnotfound = 6)
+      self$width_segments <- get2('width_segments', other_args, ifnotfound = 10)
+      self$height_segments <- get2('height_segments', other_args, ifnotfound = 6)
 
       self$set_value(
         value = get2('value', other_args, ifnotfound = NULL),
